==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyConditionsAllOfPeople.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Identifies Users and Groups that are used together
 */
@ApiModel(description = "Identifies Users and Groups that are used together")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyConditionsAllOfPeople.JSON_PROPERTY_GROUPS })
@JsonTypeName("AuthenticatorEnrollmentPolicyConditions_allOf_people")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyConditionsAllOfPeople implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GROUPS = "groups";
    private AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups groups;

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeople() {
    }

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeople groups(
            AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups groups) {

        this.groups = groups;
        return this;
    }

    /**
     * Get groups
     *
     * @return groups
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups getGroups() {
        return groups;
    }

    @JsonProperty(JSON_PROPERTY_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGroups(AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups groups) {
        this.groups = groups;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyConditionsAllOfPeople authenticatorEnrollmentPolicyConditionsAllOfPeople = (AuthenticatorEnrollmentPolicyConditionsAllOfPeople) o;
        return Objects.equals(this.groups, authenticatorEnrollmentPolicyConditionsAllOfPeople.groups);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(groups);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyConditionsAllOfPeople {\n");
        sb.append("    groups: ").append(toIndentedString(groups)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyConditionsAllOfPeople.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Identifies Users and Groups that are used together
 */
@ApiModel(description = "Identifies Users and Groups that are used together")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyConditionsAllOfPeople.JSON_PROPERTY_GROUPS })
@JsonTypeName("AuthenticatorEnrollmentPolicyConditions_allOf_people")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class AuthenticatorEnrollmentPolicyConditionsAllOfPeople implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GROUPS = "groups";
    private AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups groups;

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeople() {
    }

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeople groups(
            AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups groups) {

        this.groups = groups;
        return this;
    }

    /**
     * Get groups
     *
     * @return groups
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups getGroups() {
        return groups;
    }

    @JsonProperty(JSON_PROPERTY_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGroups(AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups groups) {
        this.groups = groups;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyConditionsAllOfPeople authenticatorEnrollmentPolicyConditionsAllOfPeople = (AuthenticatorEnrollmentPolicyConditionsAllOfPeople) o;
        return Objects.equals(this.groups, authenticatorEnrollmentPolicyConditionsAllOfPeople.groups);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(groups);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyConditionsAllOfPeople {\n");
        sb.append("    groups: ").append(toIndentedString(groups)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
